@@ -30,7 +30,12 @@ class SmartCards(object):
 			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so path.")
 					
 		elif OS in ["osx"]: 
-			self.path = "/usr/local/lib/libykcs11.dylib"
+			#self.original_path = "/usr/local/lib/libykcs11.dylib"
+			#self.path = "/usr/local/lib/libykcs11_NOTALNK.dylib"
+			self.original_path = "/usr/local/lib/opensc-pkcs11.so"
+			self.path = "/usr/local/lib/opensc-pkcs11_NOTALINK.so"
+			if not os.path.exists(self.original_path):
+				raise OSError("opensc package is not installed, run: [$ brew install yubico-piv-tool opensc].")
 
 	def scan(self, silent=False):
 
