@@ -18,11 +18,11 @@ class Installation(object):
 		response = utils.__default_response__()
 		if username == None: username = OWNER
 		home = f"{HOME_BASE}/{username}/"	
-		sudo = OWNER != username
+		sudo = True
 		
 		# users ssh directory.
 		fp = Formats.FilePath(f"{home}.ssh/")
-		if not fp.exists():
+		if not fp.exists(sudo=sudo):
 			fp.create(
 				directory=True,
 				permission=700,
@@ -35,7 +35,7 @@ class Installation(object):
 
 		# the ssh config.
 		fp = Formats.FilePath(f"{home}.ssh/config")
-		if not fp.exists():
+		if not fp.exists(sudo=sudo):
 			fp.create(
 				directory=False,
 				data="",
@@ -49,7 +49,7 @@ class Installation(object):
 
 		# the ssh known hosts.
 		fp = Formats.FilePath(f"{home}.ssh/known_hosts")
-		if not fp.exists():
+		if not fp.exists(sudo=sudo):
 			fp.create(
 				directory=False,
 				data="",
@@ -63,7 +63,7 @@ class Installation(object):
 
 		# authorized keys.
 		fp = Formats.FilePath(f"{home}.ssh/authorized_keys")
-		if not fp.exists():
+		if not fp.exists(sudo=sudo):
 			fp.create(
 				directory=False,
 				data="",
@@ -90,7 +90,7 @@ class Installation(object):
 		response = utils.__default_response__()
 		if username == None: username = OWNER
 		home = f"{HOME_BASE}/{username}/"	
-		sudo = OWNER != username
+		sudo = True
 		
 		# users ssh directory.
 		fp = Formats.FilePath(f"{home}.ssh/")
@@ -1345,14 +1345,15 @@ class SSHD(object):
 		for username in usernames:
 			
 			# non existant.
-			fp = Formats.FilePath(f"{HOME_BASE}{username}/.ssh/utils/.version.py")
+			fp = Formats.FilePath(f"{HOME_BASE}{username}/.ssh/utils/.version")
 			if not fp.exists(sudo=True): 
 				to_install.append(username)
 
 			# check version.
 			else: 
 				version = utils.__execute__(["sudo", "cat", fp.path])
-				if str(version) != str(Files.File(path=f'{SOURCE_PATH}/{VERSION}/classes/utils/.version.py', load=True).data):
+				github_version = utils.__execute__(["curl", "https://raw.githubusercontent.com/vandenberghinc/ssht00ls/master/ssht00ls/v1/classes/utils/.version?raw=true"])
+				if str(version) != str(github_version):
 					to_install.append(username)
 
 		# install.
@@ -1397,7 +1398,7 @@ class SSHD(object):
 
 			# copy.
 			fp = Formats.FilePath(f"{HOME_BASE}{username}/.ssh/utils/")
-			fp.delete(forced=True, sudo=True)
+			os.system(f"sudo rm -fr {fp.path}")
 			os.system(f"sudo cp -r {path} {fp.path}")
 			fp.ownership.set(owner=username, group=None, sudo=True)
 			fp.permission.set(permission=755, recursive=True, sudo=True)
